package svc

import (
	"code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/db"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/db/offical"
	db2 "code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/db/zhimeng"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/kuaishou"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/md"
	zhios_third_party_utils "code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/utils"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/zhimeng"
	"encoding/json"
	"github.com/tidwall/gjson"
	"xorm.io/xorm"
)

func KuaiShouUrl(eg *xorm.Engine, officialEg, zhimengEg *xorm.Engine, dbName string, tikTokArgs map[string]interface{}) *md.ConvertedUrls {

	param, kuaishouData := GetKuaishouKey(eg, officialEg, zhimengEg, dbName)
	if kuaishouData["authType"] != "2" {
		str := zhios_third_party_utils.AnyToString(tikTokArgs["external_info"])
		tikTokArgs["external_info"] = "official_" + str
	}

	arg := map[string]interface{}{
		"linkType":      tikTokArgs["linkType"],
		"linkCarrierId": tikTokArgs["gid"],
		"comments":      tikTokArgs["external_info"],
		"cpsPid":        kuaishouData["pid"],
	}
	if zhios_third_party_utils.AnyToInt64(tikTokArgs["genPoster"]) > 0 {
		arg["genPoster"] = true
	}

	param["param"] = zhios_third_party_utils.SerializeStr(arg)
	data, err := kuaishou.GetKuishouCpsUrl(kuaishouData["sign_secret"], param)
	goods := gjson.Get(data, "data").String()
	if goods == "" || err != nil {
		return nil
	}
	res := md.ConvertedUrls{
		URL:             gjson.Get(goods, "kwaiUrl").String(),
		ShortenURL:      gjson.Get(goods, "kwaiUrl").String(),
		NoOpenAppURL:    gjson.Get(goods, "linkUrl").String(),
		AppURL:          gjson.Get(goods, "kwaiUrl").String(),
		ClickUrl:        gjson.Get(goods, "kwaiUrl").String(),
		QrcodeUrl:       gjson.Get(goods, "posterContent.minaCode").String(),
		Content:         gjson.Get(goods, "commandContent").String(),
		WeChatMiniURL:   gjson.Get(goods, "minaJumpContent.pageUrl").String(),
		WeChatMiniAPPID: gjson.Get(goods, "minaJumpContent.appId").String(),
	}
	return &res
}

func KuaiShouKlGoods(eg *xorm.Engine, officialEg, zhimengEg *xorm.Engine, dbName string, tikTokArgs map[string]interface{}) *zhimeng.TikTokDetailData {
	arg := map[string]interface{}{
		"cpsLink": tikTokArgs["content"],
	}
	param, kuaishouData := GetKuaishouKey(eg, officialEg, zhimengEg, dbName)
	//if kuaishouData["authType"] != "2" {
	//	goods, _ := zhimeng.KuaiShouKlGoods(tikTokArgs)
	//	return goods
	//}
	param["param"] = zhios_third_party_utils.SerializeStr(arg)
	data, err := kuaishou.GetKuishouCpsKlGoods(kuaishouData["sign_secret"], param)
	goods := gjson.Get(data, "data.itemId").String()
	if goods == "" || err != nil {
		return nil
	}
	detail := KuaiShouDetail(eg, officialEg, zhimengEg, dbName, map[string]interface{}{"gid": []string{goods}})
	return detail
}

func GetKuaishouKey(eg *xorm.Engine, officialEg, zhimengEg *xorm.Engine, dbName string) (map[string]string, map[string]string) {
	kuaishouData := CommKuaishou(eg, officialEg, zhimengEg, dbName)
	param := map[string]string{
		"appkey":       kuaishouData["appkey"],
		"access_token": kuaishouData["token"],
	}
	return param, kuaishouData
}
func KuaiShouDetail(eg *xorm.Engine, officialEg, zhimengEg *xorm.Engine, dbName string, tikTokArgs map[string]interface{}) *zhimeng.TikTokDetailData {
	arg := map[string]interface{}{
		"itemId": []interface{}{tikTokArgs["gid"]},
	}
	param, kuaishouData := GetKuaishouKey(eg, officialEg, zhimengEg, dbName)
	//if kuaishouData["authType"] != "2" {
	//	goods, _ := zhimeng.KuaiShouDetail(tikTokArgs)
	//	return goods
	//}
	param["param"] = zhios_third_party_utils.SerializeStr(arg)
	data, err := kuaishou.GetKuishouCpsGoodsDetail(kuaishouData["sign_secret"], param)
	goods := gjson.Get(data, "data").String()
	if goods == "" || err != nil {
		return nil
	}
	var list = make([]md.KuaishouGoods, 0)
	err = json.Unmarshal([]byte(goods), &list)
	if err != nil {
		return nil
	}
	var detail = zhimeng.TikTokDetailData{}
	for _, v := range list {
		if zhios_third_party_utils.IntToStr(v.GoodsId) == zhios_third_party_utils.AnyToString(tikTokArgs["gid"]) {
			detail = CommGoodsDetail(v)
		}
	}
	return &detail
}
func CommGoodsDetail(goods md.KuaishouGoods) zhimeng.TikTokDetailData {
	var res = zhimeng.TikTokDetailData{
		Commission: zhios_third_party_utils.Float64ToStr(float64(goods.PromotionRate) / 10),
		CostPrice:  zhios_third_party_utils.Float64ToStr(float64(goods.GoodsPrice) / 100),
		GoodsID:    zhios_third_party_utils.IntToStr(goods.GoodsId),
		GoodsImg:   goods.GoodsImageUrl,
		GoodsSales: zhios_third_party_utils.IntToStr(goods.SalesTip),
		GoodsTitle: goods.GoodsTitle,
		Price:      zhios_third_party_utils.Float64ToStr(float64(goods.ZkGoodsPrice) / 100),
		ShopID:     zhios_third_party_utils.IntToStr(goods.MallId),
		ShopName:   goods.MallName,
	}
	img, ok := goods.GoodsGalleryUrls.([]interface{})
	res.Imgs = make([]string, 0)
	if ok {
		for _, v := range img {
			res.Imgs = append(res.Imgs, zhios_third_party_utils.AnyToString(v))
		}
	}
	detailImg, ok := goods.ItemDescUrls.([]interface{})
	res.DetailImgs = make([]string, 0)
	if ok {
		for _, v := range detailImg {
			res.DetailImgs = append(res.DetailImgs, zhios_third_party_utils.AnyToString(v))
		}
	}
	return res
}

func CommKuaishou(eg *xorm.Engine, officialEg, zhimengEg *xorm.Engine, dbName string) map[string]string {
	kuaishouAppkey := offical.MasterListCfgGetOneData(officialEg, "0", "kuaishou_appkey")
	kuaishouAppSecret := offical.MasterListCfgGetOneData(officialEg, "0", "kuaishou_app_secret")
	kuaishouSignSecret := offical.MasterListCfgGetOneData(officialEg, "0", "kuaishou_sign_secret")
	kuaishouToken := offical.MasterListCfgGetOneData(officialEg, "0", "kuaishou_token")
	kuaishouPid := offical.MasterListCfgGetOneData(officialEg, "0", "kuaishou_pid")
	puid := AppUserListPuidWithDb(officialEg, dbName)
	puidKuaishouAppkey := offical.MasterListCfgGetOneData(officialEg, puid, "kuaishou_appkey")
	if puidKuaishouAppkey != "" {
		kuaishouAppkey = puidKuaishouAppkey
	}
	puidKuaishouSignSecret := offical.MasterListCfgGetOneData(officialEg, puid, "kuaishou_sign_secret")
	if puidKuaishouSignSecret != "" {
		kuaishouSignSecret = puidKuaishouSignSecret
	}
	puidKuaishouToken := offical.MasterListCfgGetOneData(officialEg, puid, "kuaishou_token")
	if puidKuaishouToken != "" {
		kuaishouToken = puidKuaishouToken
	}
	puidKuaishouPid := offical.MasterListCfgGetOneData(officialEg, puid, "kuaishou_pid")
	if puidKuaishouPid != "" {
		kuaishouPid = puidKuaishouPid
	}
	cfg, _ := db.SysUnionByKuaishouByUseByAuth(eg, dbName)
	authType := ""
	pid := kuaishouPid
	if cfg != nil && cfg.AuthType == 2 { //自有
		authType = zhios_third_party_utils.IntToStr(cfg.AuthType)
		kuaishouToken = gjson.Get(cfg.KeyData, "teamAccessToken").String()
		pid = gjson.Get(cfg.KeyData, "pid").String()
	} else {
		res := OfficialCommKuaishou(officialEg, zhimengEg)
		res["own_appkey"] = kuaishouAppkey
		res["own_app_secret"] = kuaishouAppSecret
		res["own_sign_secret"] = kuaishouSignSecret
		return res
	}
	res := map[string]string{
		"authType":    authType,
		"appkey":      kuaishouAppkey,
		"token":       kuaishouToken,
		"pid":         pid,
		"app_secret":  kuaishouAppSecret,
		"sign_secret": kuaishouSignSecret,
	}
	return res
}
func OfficialCommKuaishou(officialEg, zhimengEg *xorm.Engine) map[string]string {
	kuaishouAppkey := offical.MasterListCfgGetOneData(officialEg, "0", "kuaishou_kfx_appkey")
	kuaishouAppSecret := offical.MasterListCfgGetOneData(officialEg, "0", "kuaishou_kfx_app_secret")
	kuaishouSignSecret := offical.MasterListCfgGetOneData(officialEg, "0", "kuaishou_kfx_sign_secret")
	authType := "0"
	kuaishouToken := db2.MasterListCfgGetOneData(zhimengEg, "0", "kuaishou_official_access_token")
	kuaishouPid := offical.MasterListCfgGetOneData(officialEg, "0", "kuaishou_official_pid")
	res := map[string]string{
		"pid":         kuaishouPid,
		"authType":    authType,
		"appkey":      kuaishouAppkey,
		"token":       kuaishouToken,
		"app_secret":  kuaishouAppSecret,
		"sign_secret": kuaishouSignSecret,
	}
	return res
}

func AppUserListPuidWithDb(officialEg *xorm.Engine, dbName string) string {
	appList := offical.GetUserAppList(officialEg, dbName)
	uid := "0"
	if appList != nil && appList.Puid > 0 {
		uid = zhios_third_party_utils.IntToStr(appList.Puid)
	}
	return uid
}
