package svc

import (
	"code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/db"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/tik_tok"
	zhios_third_party_utils "code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/utils"

	"fmt"
	"strings"
	"xorm.io/xorm"
)

func CommTik(eg *xorm.Engine, dbName, url string) map[string]string {
	activityId := 0
	teamToken := ""
	commission := ""
	if strings.Contains(url, "ecommerce") {
		tikTokBase, _ := tik_tok.Base(eg, dbName, "")
		tikTokBase.ExtendTeamTokenMap = GetTikTokTeamTokenEg(eg, dbName, "")
		isSet := 0
		for _, v1 := range tikTokBase.ExtendTeamTokenMap {
			if isSet == 1 {
				continue
			}
			if v1 != "" {
				rgs := map[string]string{
					"appkey":       tikTokBase.ApiTeamAppKey,
					"appSecret":    tikTokBase.ApiTeamAppSecret,
					"acctoken":     zhios_third_party_utils.AnyToString(v1),
					"activity_url": url,
				}
				urlMap := tik_tok.ColonelMultiParseActivityUrl(rgs)
				if urlMap[url].ActivityId != 0 {
					isSet = 1
					activityId = urlMap[url].ActivityId
					teamToken = zhios_third_party_utils.AnyToString(v1)
					commission = zhios_third_party_utils.Float64ToStr(float64(urlMap[url].CommissionRate) / 100)
				}
			}
		}
	}
	res := map[string]string{
		"tik_activity_id":     zhios_third_party_utils.IntToStr(activityId),
		"tik_team_token":      teamToken,
		"tik_team_commission": commission,
	}
	return res
}

func GetTikTokTeamTokenEg(eg *xorm.Engine, dbName, url string) map[string]interface{} {
	tmp := map[string]interface{}{}
	zhiosOpenSelectionLibraryMasterId := db.SysCfgGetWithDb(eg, dbName, "zhios_open_selection_library_master_id")
	if zhiosOpenSelectionLibraryMasterId == "" {
		return tmp
	}
	bizData := map[string]interface{}{
		"mid": zhiosOpenSelectionLibraryMasterId,
	}
	returnData, err := OauthApiReqEg(eg, dbName, "http://zhios-open:5006", bizData, "inapi.selection_library.team_info_more", "1.0")
	if returnData == nil || err != nil {
		return tmp
	}
	data := returnData.Data.(map[string]interface{})
	return data

}
func GetKuaishouTeamTokenEg(eg *xorm.Engine, dbName, url string) map[string]interface{} {
	tmp := map[string]interface{}{}
	zhiosOpenSelectionLibraryMasterId := db.SysCfgGetWithDb(eg, dbName, "zhios_open_kuaishou_selection_library_master_id")
	if zhiosOpenSelectionLibraryMasterId == "" {
		return tmp
	}
	bizData := map[string]interface{}{
		"mid": zhiosOpenSelectionLibraryMasterId,
	}
	returnData, err := OauthApiReqEg(eg, dbName, url, bizData, "inapi.selection_library.kuaishou_team_info_more", "1.0")
	if returnData == nil || err != nil {
		return tmp
	}
	data := returnData.Data.(map[string]interface{})
	return data

}

func OauthApiReqEg(eg *xorm.Engine, dbName, url string, bizData map[string]interface{}, method, version string) (*zhios_third_party_utils.ReturnDataResp, error) {
	openAppKey := db.SysCfgGetWithDb(eg, dbName, "zhios_open_app_key")
	openAppSecret := db.SysCfgGetWithDb(eg, dbName, "zhios_open_app_secret")
	// 创建请求
	openClient, err := zhios_third_party_utils.NewOpenPlatformReqClient(openAppKey, method, version, openAppSecret, bizData)
	if err != nil {
		return nil, err
	}
	openClient.Url = url
	fmt.Println("return :", openClient.ReturnData)
	// 发送请求
	err = openClient.SetBizDataToParams().CreateSign().CurlOpen()
	if err != nil {
		return nil, err
	}
	return &openClient.ReturnData, nil
}
