package dataoke

import (
	zhios_third_party_utils "code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/utils"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/utils/cache"
	"encoding/json"
	"errors"
	"fmt"
	"github.com/tidwall/gjson"
)

type ContentParse struct {
	ItemId         string      `json:"itemId"`
	ItemLink       string      `json:"itemLink"`
	ItemName       string      `json:"itemName"`
	DataType       string      `json:"dataType"`
	PlatType       string      `json:"platType"`
	MainPic        string      `json:"mainPic"`
	MonthSales     interface{} `json:"monthSales"`
	OriginalPrice  interface{} `json:"originalPrice"`
	ActualPrice    interface{} `json:"actualPrice"`
	CommissionRate interface{} `json:"commissionRate"`
	CouponPrice    interface{} `json:"coupon_price"`
	Url            string      `json:"url"`
}

func DaTaoKeContentParse(content string) (data ContentParse, err error) {
	key := "new_" + content
	get, err := cache.GetString(key)
	if get == "" || err != nil {
		params := map[string]string{
			"version": "v1.0.0",
			"content": key,
		}
		resp, err := SendReq("https://openapi.dataoke.com/api/dels/kit/contentParse", params)
		if err != nil {
			return data, err
		}
		list := gjson.Get(string(resp), "data").String()
		err = json.Unmarshal([]byte(list), &data)
		if err != nil {
			return data, err
		}
		if data.DataType != "goods" {
			return data, errors.New("不是商品")
		}
		if data.ItemId != "" {
			_, err := cache.SetEx(content, zhios_third_party_utils.SerializeStr(data), 15*86400)
			fmt.Println(err)
		}
	} else {
		json.Unmarshal([]byte(get), &data)
	}
	return data, nil
}
