package tik_tok

import (
	zhios_third_party_utils "code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/utils"
	"encoding/json"
	"github.com/tidwall/gjson"
	"strings"
)

func CsjpOrderList(args map[string]string) map[string]interface{} {
	params := map[string]interface{}{
		"size":       zhios_third_party_utils.StrToInt(args["size"]),
		"cursor":     args["cursor"],
		"start_time": zhios_third_party_utils.StrToInt(args["start_time"]),
		"end_time":   zhios_third_party_utils.StrToInt(args["end_time"]),
		"time_type":  args["time_type"],
		"order_type": zhios_third_party_utils.StrToInt(args["order_type"]),
	}
	if args["order_ids"] != "" {
		params["order_ids"] = strings.Split(args["order_ids"], ",")
	}
	send, err := CsjpSend(args["app_id"], args["app_secret"], "order/search", params)
	var data = map[string]interface{}{}
	if err != nil {
		return data
	}
	order := gjson.Get(send, "data.orders").String()
	data["cursor"] = gjson.Get(send, "data.cursor").String()
	var tmpList = make([]interface{}, 0)
	err = json.Unmarshal([]byte(order), &tmpList)
	if err != nil {
		return data
	}
	var orderTmp = make([]map[string]string, 0)
	statusArr := map[string]string{
		"PAY_SUCC": "订单付款",
		"REFUND":   "订单退款",
		"SETTLE":   "订单结算",
		"CONFIRM":  "订单成功",
	}
	for _, v := range tmpList {

		tmp := CsjpCommOrder(v, statusArr, "dk")
		if tmp["oid"] == "" {
			continue
		}
		orderTmp = append(orderTmp, tmp)
	}
	data["order"] = orderTmp
	return data
}
func CsjpCommOrder(v interface{}, statusArr map[string]string, types string) map[string]string {
	tmp := make(map[string]string)
	goods := v.(map[string]interface{})
	methodType := "csjp"
	if zhios_third_party_utils.AnyToString(goods["media_type_name"]) == "Live" {
		methodType = "csjp_live"
	}
	tmp = map[string]string{
		"pid":         zhios_third_party_utils.AnyToString(goods["app_id"]),
		"oid":         zhios_third_party_utils.AnyToString(goods["order_id"]),
		"info":        zhios_third_party_utils.AnyToString(goods["product_name"]),
		"num":         "1",
		"type":        methodType,
		"product_id":  zhios_third_party_utils.AnyToString(goods["product_id"]),
		"product_img": zhios_third_party_utils.AnyToString(goods["product_img"]),
		"payment":     zhios_third_party_utils.AnyToString(zhios_third_party_utils.AnyToFloat64(goods["total_pay_amount"]) / 100),
		"status":      statusArr[zhios_third_party_utils.AnyToString(goods["flow_point"])],
		"create_time": zhios_third_party_utils.Int64ToStr(zhios_third_party_utils.TimeStdParseUnix(zhios_third_party_utils.AnyToString(goods["pay_success_time"]))),
		"update_time": zhios_third_party_utils.Int64ToStr(zhios_third_party_utils.TimeStdParseUnix(zhios_third_party_utils.AnyToString(goods["update_time"]))),
		"refund_time": "",
		"lm_js_time":  "",
		"mid":         "",
	}
	if zhios_third_party_utils.AnyToString(goods["after_sales_status"]) == "2" {
		tmp["status"] = "订单退款"
	}
	external_info := zhios_third_party_utils.AnyToString(goods["external_info"])
	tmp["is_share"] = "0"
	split := strings.Split(external_info, "_")
	if len(split) > 1 {
		if split[0] == "s" {
			tmp["is_share"] = "1"
		}
		if split[0] == "cloud" {
			tmp["is_share"] = "3"
		}
		if split[0] == "f" {
			tmp["is_share"] = "2"
		}
		if split[0] == "sef" {
			tmp["is_share"] = "4"
		}
		if split[0] == "sharesef" {
			tmp["is_share"] = "5"
		}
		if split[0] == "moref" {
			tmp["is_share"] = "6"
		}
		tmp["uid"] = split[1]
		if len(split) >= 3 {
			tmp["mid"] = split[2]
		}
		if len(split) >= 4 {
			tmp["team_type"] = split[3]
		}
	}
	tmp["commission"] = zhios_third_party_utils.AnyToString(zhios_third_party_utils.AnyToFloat64(goods["estimated_commission"]) / 100)
	if zhios_third_party_utils.AnyToFloat64(goods["ads_real_commission"]) > 0 {
		tmp["commission"] = zhios_third_party_utils.AnyToString(zhios_third_party_utils.AnyToFloat64(goods["ads_real_commission"]) / 100)
	}

	if zhios_third_party_utils.AnyToString(goods["refund_time"]) != "" {
		tmp["refund_time"] = zhios_third_party_utils.Int64ToStr(zhios_third_party_utils.TimeStdParseUnix(zhios_third_party_utils.AnyToString(goods["pay_success_time"])))
	}
	if zhios_third_party_utils.AnyToString(goods["settle_time"]) != "" {
		tmp["lm_js_time"] = zhios_third_party_utils.Int64ToStr(zhios_third_party_utils.TimeStdParseUnix(zhios_third_party_utils.AnyToString(goods["settle_time"])))
	}
	return tmp
}
