package tik_tok

import (
	"code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/md"
	zhios_third_party_utils "code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/utils"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/zhimeng"
	"encoding/json"
	"fmt"
	"github.com/jinzhu/copier"
	"github.com/syyongx/php2go"
	"github.com/tidwall/gjson"
	"strings"
)

//抖音商品
func GoodsList(args map[string]string) []TikTokGoods {
	sortArr := map[string]map[string]string{
		"default":        {"search_type": "0", "sort_type": "0"},
		"qhPriceDesc":    {"search_type": "2", "sort_type": "1"},
		"qhPriceAsc":     {"search_type": "2", "sort_type": "0"},
		"commissionDesc": {"search_type": "4", "sort_type": "1"},
		"commissionAsc":  {"search_type": "4", "sort_type": "1"},
		"salesDesc":      {"search_type": "1", "sort_type": "1"},
		"salesAsc":       {"search_type": "1", "sort_type": "1"},
	}
	params := map[string]interface{}{
		"search_type":  sortArr[args["sort"]]["search_type"],
		"sort_type":    sortArr[args["sort"]]["sort_type"],
		"page":         args["page"],
		"page_size":    args["page_size"],
		"share_status": "1",
	}
	if args["title"] != "" {
		params["title"] = args["title"]
	}
	if args["first_cids"] != "" {
		params["first_cids"] = []string{args["first_cids"]}
	}
	if args["price_min"] != "" {
		params["price_min"] = zhios_third_party_utils.IntToStr(int(zhios_third_party_utils.StrToFloat64(args["price_min"]) * 100))
	}
	if args["price_max"] != "" {
		params["price_max"] = zhios_third_party_utils.IntToStr(int(zhios_third_party_utils.StrToFloat64(args["price_max"]) * 100))
	}
	if args["sell_num_min"] != "" {
		params["sell_num_min"] = args["sell_num_min"]
	}
	if args["sell_num_max"] != "" {
		params["sell_num_max"] = args["sell_num_max"]
	}
	if args["cos_fee_min"] != "" {
		params["cos_fee_min"] = zhios_third_party_utils.IntToStr(int(zhios_third_party_utils.StrToFloat64(args["cos_fee_min"]) * 100))
	}
	if args["cos_fee_max"] != "" {
		params["cos_fee_max"] = zhios_third_party_utils.IntToStr(int(zhios_third_party_utils.StrToFloat64(args["cos_fee_max"]) * 100))
	}
	if args["cos_ratio_min"] != "" {
		params["cos_ratio_min"] = zhios_third_party_utils.IntToStr(int(zhios_third_party_utils.StrToFloat64(args["cos_ratio_min"]) * 100))
	}
	if args["cos_ratio_max"] != "" {
		params["cos_ratio_max"] = zhios_third_party_utils.IntToStr(int(zhios_third_party_utils.StrToFloat64(args["cos_ratio_max"]) * 100))
	}
	send, err := Send(args["appkey"], args["appSecret"], "alliance.materialsProductsSearch", params, args["acctoken"])
	var goodsList = make([]TikTokGoods, 0)
	fmt.Println("抖音商品", args, send, err)
	product := gjson.Get(send, "data.products").String()
	if err != nil || product == "" {
		return goodsList
	}
	var lmData struct {
		Data struct {
			Products []TikTokGoodsLm `json:"products"`
		} `json:"data"`
	}
	err = json.Unmarshal([]byte(send), &lmData)
	if err != nil {
		fmt.Println("抖音商品1", err)

		return goodsList
	}
	for _, v := range lmData.Data.Products {
		tmp := CommGoodsDetail(v)
		goodsList = append(goodsList, tmp)
	}
	return goodsList
}

//详情
func GetDetailOld(args map[string]string) TikTokGoods {
	params := map[string]interface{}{"product_ids": []string{args["id"]}, "with_share_status": true}
	send, err := Send(args["appkey"], args["appSecret"], "alliance.materialsProductsDetails", params, args["acctoken"])
	var goodsList = TikTokGoods{}
	product := gjson.Get(send, "data.products").String()
	if err != nil || product == "" {
		return goodsList
	}
	var lmData struct {
		Data struct {
			Products []TikTokGoodsLm `json:"products"`
		} `json:"data"`
	}
	err = json.Unmarshal([]byte(send), &lmData)
	if err != nil {
		return goodsList
	}
	for _, v := range lmData.Data.Products {
		tmp := CommGoodsDetail(v)
		if tmp.GoodsID == args["id"] {
			return tmp
		}
	}
	//
	return goodsList
}
func GetDetail(args map[string]string) TikTokGoods {
	params := map[string]interface{}{"product_ids": []string{args["id"]}, "fields": "base_info,promotion_info,month_sale_data,share_info,coupon_info,shop_info"}
	send, err := Send(args["appkey"], args["appSecret"], "buyin.kolProductsDetail", params, args["acctoken"])
	var goodsList = TikTokGoods{}
	product := gjson.Get(send, "data.products").String()
	if err != nil || product == "" {
		return goodsList
	}
	var lmData struct {
		Data struct {
			Products []TikTokGoodsLmNew `json:"products"`
		} `json:"data"`
	}
	err = json.Unmarshal([]byte(send), &lmData)
	if err != nil {
		return goodsList
	}
	for _, v := range lmData.Data.Products {
		tmp1 := TikTokGoodsLm{
			CosFee:         int64(v.PromotionInfo.CosFee),
			CosRatio:       float64(v.PromotionInfo.CosRatio),
			CouponPrice:    int64(v.CouponInfo.CouponPrice),
			Cover:          v.BaseInfo.Cover,
			DetailURL:      v.BaseInfo.DetailUrl,
			FirstCid:       int64(v.BaseInfo.FirstCid),
			InStock:        v.BaseInfo.InStock,
			Price:          int64(v.BaseInfo.Price),
			ProductID:      v.BaseInfo.ProductId,
			Sales:          int64(v.BaseInfo.Sales),
			SecondCid:      int64(v.BaseInfo.SecondCid),
			Sharable:       v.ShareInfo.Sharable,
			ShopID:         int64(v.ShopInfo.ShopId),
			ShopName:       v.ShopInfo.ShopName,
			ThirdCid:       int64(v.BaseInfo.ThirdCid),
			Title:          v.BaseInfo.Title,
			Imgs:           v.BaseInfo.Imgs,
			ShopTotalScore: v.ShopInfo.ShopTotalScore,
		}
		if v.PromotionInfo.KolCosFee != v.PromotionInfo.CosFee {
			tmp1.CosFee = int64(v.PromotionInfo.KolCosFee)
			tmp1.CosRatio = float64(v.PromotionInfo.KolCosRatio)
		}
		tmp := CommGoodsDetail(tmp1)
		if tmp.GoodsID == args["id"] {
			return tmp
		}
	}
	//
	return goodsList
}
func GetDetailSku(args map[string]string, id int64) md.SkuData {
	params := map[string]interface{}{"product_id": id}
	send, err := Send(args["appkey"], args["appSecret"], "buyin.productSkus", params, args["acctoken"])
	var goodsList = md.SkuData{}
	product := gjson.Get(send, "data").String()
	if err != nil || product == "" {
		return goodsList
	}
	respstr := strings.ReplaceAll(string(product), "\"pictures\":[]", "\"pictures\":{}")
	if err = json.Unmarshal([]byte(respstr), &goodsList); err != nil {
		return goodsList
	}
	return goodsList
}

func OpenStoreDel(args map[string]interface{}) (string, error) {
	/**
	products	[]AddStoreProductInfo
	商品信息，最多20个商品
	product_id	int64	3450632721376902816	商品ID
	promotion_id	int64	3450632721374033833	推广ID
	need_hide	bool	false	是否隐藏（true代表隐藏，false代表显示）
	pick_extra	string	fasdfkl	自定义参数，携带到订单（只允许 数字、字母和_，限制长度为20）
	keep_picksource	bool	true	是否保留商品链接原有选品来源，默认不保留（加橱窗时默认会生成新的选品来源参数覆盖旧参数，转链的自定义参数也会失效，此时选品来源为当前加橱窗应用），keep_picksource 为 true 时保留原有选品来源
	*/
	fmt.Println(args)
	params := map[string]interface{}{"products": args["products"]}
	send, err := OpenSendApi("alliance/kol/store/remove/?open_id="+zhios_third_party_utils.AnyToString(args["open_id"]), params, zhios_third_party_utils.AnyToString(args["acctoken"]))
	fmt.Println(send)
	fmt.Println(err)
	return send, err
}
func OpenStoreList(args map[string]interface{}) (string, error) {
	/**
	products	[]AddStoreProductInfo
	商品信息，最多20个商品
	product_id	int64	3450632721376902816	商品ID
	promotion_id	int64	3450632721374033833	推广ID
	need_hide	bool	false	是否隐藏（true代表隐藏，false代表显示）
	pick_extra	string	fasdfkl	自定义参数，携带到订单（只允许 数字、字母和_，限制长度为20）
	keep_picksource	bool	true	是否保留商品链接原有选品来源，默认不保留（加橱窗时默认会生成新的选品来源参数覆盖旧参数，转链的自定义参数也会失效，此时选品来源为当前加橱窗应用），keep_picksource 为 true 时保留原有选品来源
	*/
	fmt.Println(args)
	params := map[string]interface{}{"page": args["page"], "page_size": args["page_size"]}
	send, err := OpenSendApi("alliance/kol/store/list/?open_id="+zhios_third_party_utils.AnyToString(args["open_id"]), params, zhios_third_party_utils.AnyToString(args["acctoken"]))
	fmt.Println(send)
	fmt.Println(err)
	return send, err
}

//详情
func GetDetailMore(args map[string]string) *[]TikTokGoods {
	productIds := strings.Split(args["id"], ",")
	if len(productIds) == 0 {
		return nil
	}
	params := map[string]interface{}{"product_ids": productIds, "with_share_status": true}
	send, err := Send(args["appkey"], args["appSecret"], "alliance.materialsProductsDetails", params, args["acctoken"])
	var goodsList = make([]TikTokGoods, 0)
	product := gjson.Get(send, "data.products").String()
	if err != nil || product == "" {
		return nil
	}
	var lmData struct {
		Data struct {
			Products []TikTokGoodsLm `json:"products"`
		} `json:"data"`
	}
	err = json.Unmarshal([]byte(send), &lmData)
	if err != nil {
		return nil
	}
	for _, v := range lmData.Data.Products {
		tmp := CommGoodsDetail(v)
		goodsList = append(goodsList, tmp)
	}
	//
	return &goodsList
}
func GetKlGoods(args map[string]string) TikTokGoods {
	content, _ := php2go.Base64Decode(args["content"])
	params := map[string]interface{}{"command": content}
	send, err := Send(args["appkey"], args["appSecret"], "buyin.shareCommandParse", params, args["acctoken"])
	var goodsList = TikTokGoods{}
	product := gjson.Get(send, "data.product_info").String()
	if err != nil || product == "" {
		return goodsList
	}
	args["id"] = gjson.Get(product, "product_id").String()
	goodsList = GetDetail(args)
	return goodsList
}
func GetKlGoodsNew(args map[string]string) TikTokGoods {
	content, _ := php2go.Base64Decode(args["content"])
	params := map[string]interface{}{"command": content}
	send, err := Send(args["appkey"], args["appSecret"], "buyin.doukeCommandParseAndShare", params, args["acctoken"])
	var goodsList = TikTokGoods{}
	ActivityId := gjson.Get(send, "data.command_info.activity_info.material_id").Int()
	if ActivityId > 0 {
		goodsList.ActivityId = zhios_third_party_utils.Int64ToStr(gjson.Get(send, "data.command_info.activity_info.material_id").Int())
		return goodsList
	}
	product := gjson.Get(send, "data.command_info.product_info").String()
	if err != nil || product == "" {
		return goodsList
	}
	args["id"] = gjson.Get(product, "product_id").String()
	goodsList = GetDetail(args)
	return goodsList
}
func CommGoodsDetail(goods TikTokGoodsLm) TikTokGoods {
	ShopTotalScores, ok := goods.ShopTotalScore.(ShopTotalScore)
	ShopTotalScore := ShopTotalScore1{}
	if ok {
		ShopTotalScore = ShopTotalScore1{
			LogisticsScore: ShopTotalScoreData1{
				Level: zhios_third_party_utils.IntToStr(ShopTotalScores.LogisticsScore.Level),
				Score: ShopTotalScores.LogisticsScore.Score,
				Text:  ShopTotalScores.LogisticsScore.Text,
			},
			ProductScore: ShopTotalScoreData1{
				Level: zhios_third_party_utils.IntToStr(ShopTotalScores.ProductScore.Level),
				Score: ShopTotalScores.ProductScore.Score,
				Text:  ShopTotalScores.ProductScore.Text,
			},
			ServiceScore: ShopTotalScoreData1{
				Level: zhios_third_party_utils.IntToStr(ShopTotalScores.ServiceScore.Level),
				Score: ShopTotalScores.ServiceScore.Score,
				Text:  ShopTotalScores.ServiceScore.Text,
			},
		}
	}

	var tmp = TikTokGoods{
		Commission:        zhios_third_party_utils.AnyToString(goods.CosRatio),
		CostPrice:         zhios_third_party_utils.Float64ToStr(zhios_third_party_utils.AnyToFloat64(goods.Price) / 100),
		DetailURL:         zhios_third_party_utils.AnyToString(goods.DetailURL),
		GoodsID:           zhios_third_party_utils.AnyToString(goods.ProductID),
		GoodsImg:          zhios_third_party_utils.AnyToString(goods.Cover),
		GoodsSales:        zhios_third_party_utils.AnyToString(goods.Sales),
		GoodsTitle:        zhios_third_party_utils.AnyToString(goods.Title),
		Imgs:              goods.Imgs,
		InStock:           zhios_third_party_utils.AnyToString(goods.InStock),
		Price:             zhios_third_party_utils.Float64ToStr(zhios_third_party_utils.AnyToFloat64(goods.CouponPrice) / 100),
		Sharable:          zhios_third_party_utils.AnyToString(goods.Sharable),
		ShopID:            zhios_third_party_utils.AnyToString(goods.ShopID),
		ShopName:          zhios_third_party_utils.AnyToString(goods.ShopName),
		Cid:               zhios_third_party_utils.AnyToString(goods.FirstCid),
		ActivityStartTime: goods.ActivityStartTime,
		ActivityEndTime:   goods.ActivityEndTime,
		ShopTotalScore:    ShopTotalScore,
		YhqPrice:          "0",
		ServiceRatio:      goods.ServiceRatio,
		ApplyId:           zhios_third_party_utils.Int64ToStr(goods.ApplyId),
	}
	if goods.ActivityCosRatio > 0 {
		tmp.PublicCommission = tmp.Commission
		tmp.Commission = zhios_third_party_utils.AnyToString(goods.ActivityCosRatio / 100)
	}
	if zhios_third_party_utils.StrToFloat64(tmp.Price) == 0 {
		tmp.Price = tmp.CostPrice
	} else {
		tmp.YhqPrice = zhios_third_party_utils.Float64ToStr(zhios_third_party_utils.AnyToFloat64(goods.Price)/100 - zhios_third_party_utils.AnyToFloat64(goods.CouponPrice)/100)
	}
	if len(tmp.Imgs) == 0 {
		tmp.Imgs = []string{tmp.GoodsImg}
	}
	return tmp

}
func OwnTikTokGoodsKlNew(tikTokBase *md.TikTokBase, tikTokArgs map[string]interface{}) (*zhimeng.TikTokDetailData, error) {
	args := map[string]string{
		"appkey":    tikTokBase.ApiGoodsAppKey,
		"appSecret": tikTokBase.ApiGoodsAppSecret,
		"content":   php2go.Base64Encode(tikTokArgs["content"].(string)),
		"acctoken":  tikTokBase.SysGoodsAccessToken,
	}
	for k, v := range args {
		if v == "<nil>" {
			args[k] = ""
		}
	}
	var data = zhimeng.TikTokDetailData{}
	goods := GetKlGoodsNew(args)
	if goods.ActivityId != "" {
		data.ActivityId = goods.ActivityId
		return &data, nil
	}

	if goods.GoodsID == "" {
		return nil, nil
	}
	err := copier.Copy(&data, goods)
	if err != nil {
		return nil, nil
	}
	if zhios_third_party_utils.StrToFloat64(data.YhqPrice) > 0 {
		data.Price = data.CostPrice
	}
	return &data, nil
}
