package zhimeng

import (
	"code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/md"
	zhios_third_party_utils "code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/utils"
	"encoding/json"
	"fmt"
)

func PDDConvertUrl(ak, sk, itemId, pid, promoId, couponPrice, isWxMini, isBindUrl, isShare string) (*md.ConvertedUrls, error) {
	args := map[string]interface{}{
		"appkey":                       ak,
		"secret_key":                   sk,
		"gid":                          itemId,
		"goods_sign":                   itemId,
		"pid":                          pid,
		"open_app":                     "",       // 具体规则请看智盟
		"link_type":                    "",       // todo 这几项按理来说做成配置项
		"generate_we_app":              isWxMini, // 生成微信小程序链接
		"generate_authority_url_onoff": isBindUrl,
		"custom_parameters":            promoId,
		"is_share":                     isShare,
	}
	//generate_authority_url_onoff  0不会调授权链接  1会先跳授权链接
	fmt.Println("拼多多：", args)
	resp, err := Send("pdd", "get_buy_url", args)
	if err != nil {
		return nil, err
	}
	var tmp struct {
		Data struct {
			URL          string `json:"url"`
			OpenAppURL   string `json:"open_app_url"`
			NoOpenAppURL string `json:"no_open_app_url"`
			SchemaURL    string `json:"schema_url"`
			PagePath     string `json:"page_path"`
		} `json:"data"`
	}
	if err = json.Unmarshal(resp, &tmp); err != nil {
		return nil, err
	}
	return &md.ConvertedUrls{
		ItemId:         itemId,
		URL:            tmp.Data.URL,
		ShortenURL:     tmp.Data.NoOpenAppURL,
		NoOpenAppURL:   tmp.Data.OpenAppURL,
		AppURL:         tmp.Data.SchemaURL,
		HasCoupon:      false,
		CommissionRate: couponPrice,
	}, nil
}

//生成多多进宝频道推广
func PDDActivityConvertUrl(ak, sk, resourceType, pid, promoId, url string, isShare int) (*md.ConvertedUrls, error) {
	args := map[string]interface{}{
		"appkey":            ak,
		"secret_key":        sk,
		"resource_type":     resourceType,
		"pid":               pid,
		"url":               url,
		"custom_parameters": promoId,
		"is_share":          zhios_third_party_utils.IntToStr(isShare),
	}
	//generate_authority_url_onoff  0不会调授权链接  1会先跳授权链接
	fmt.Println("拼多多：", args)

	resp, err := Send("pdd", "get_main_theme_url", args)
	if err != nil {
		return nil, err
	}
	var tmp struct {
		Data struct {
			URL          string `json:"url"`
			OpenAppURL   string `json:"open_app_url"`
			NoOpenAppURL string `json:"no_open_app_url"`
			SchemaURL    string `json:"schema_url"`
			PagePath     string `json:"page_path"`
		} `json:"data"`
	}
	if err = json.Unmarshal(resp, &tmp); err != nil {
		return nil, err
	}
	return &md.ConvertedUrls{
		URL:           tmp.Data.URL,
		ShortenURL:    tmp.Data.NoOpenAppURL,
		NoOpenAppURL:  tmp.Data.OpenAppURL,
		AppURL:        tmp.Data.SchemaURL,
		WeChatMiniURL: tmp.Data.PagePath,
	}, nil
}

//生成商城-频道推广链接
func PDDActivityStoreConvertUrl(ak, sk, resourceType, pid, promoId, url string, isShare int) (*md.ConvertedUrls, error) {
	args := map[string]interface{}{
		"appkey":            ak,
		"secret_key":        sk,
		"channel_type":      resourceType,
		"pid":               pid,
		"custom_parameters": promoId,
		"is_share":          zhios_third_party_utils.IntToStr(isShare),
	}
	//generate_authority_url_onoff  0不会调授权链接  1会先跳授权链接
	fmt.Println("拼多多：", args)

	resp, err := Send("pdd", "get_prom_url", args)
	if err != nil {
		return nil, err
	}
	var tmp struct {
		Data struct {
			URL          string `json:"url"`
			OpenAppURL   string `json:"open_app_url"`
			NoOpenAppURL string `json:"no_open_app_url"`
			SchemaURL    string `json:"schema_url"`
			PagePath     string `json:"page_path"`
		} `json:"data"`
	}
	if err = json.Unmarshal(resp, &tmp); err != nil {
		return nil, err
	}
	return &md.ConvertedUrls{
		URL:           tmp.Data.URL,
		ShortenURL:    tmp.Data.NoOpenAppURL,
		NoOpenAppURL:  tmp.Data.OpenAppURL,
		AppURL:        tmp.Data.SchemaURL,
		WeChatMiniURL: tmp.Data.PagePath,
	}, nil
}

//生成营销工具推广链接
func PDDActivitySaleConvertUrl(ak, sk, resourceType, pid, promoId, url string, isShare int) (*md.ConvertedUrls, error) {
	args := map[string]interface{}{
		"appkey":            ak,
		"secret_key":        sk,
		"channel_type":      resourceType,
		"pid":               pid,
		"custom_parameters": promoId,
		"is_share":          zhios_third_party_utils.IntToStr(isShare),
	}
	//generate_authority_url_onoff  0不会调授权链接  1会先跳授权链接
	fmt.Println("拼多多：", args)

	resp, err := Send("pdd", "get_rp_url", args)
	if err != nil {
		return nil, err
	}
	var tmp struct {
		Data struct {
			URL          string `json:"url"`
			OpenAppURL   string `json:"open_app_url"`
			NoOpenAppURL string `json:"no_open_app_url"`
			SchemaURL    string `json:"schema_url"`
			PagePath     string `json:"page_path"`
		} `json:"data"`
	}
	if err = json.Unmarshal(resp, &tmp); err != nil {
		return nil, err
	}
	return &md.ConvertedUrls{
		URL:           tmp.Data.URL,
		ShortenURL:    tmp.Data.NoOpenAppURL,
		NoOpenAppURL:  tmp.Data.OpenAppURL,
		AppURL:        tmp.Data.SchemaURL,
		WeChatMiniURL: tmp.Data.PagePath,
	}, nil
}
