package zhimeng

import (
	"code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/md"
	zhios_third_party_utils "code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/utils"
	"encoding/json"
	"github.com/syyongx/php2go"
	"strings"
)

type TikTokArgs struct {
	Keyword             string
	PageSize            string
	Sort                string
	StartPrice          string
	EndPrice            string
	StartCommissionRate string
	EndCommissionRate   string
	Page                string
	CategoryId          string
	StartSales          string
	EndSales            string
}
type TikTokData struct {
	Commission        string   `json:"commission"`
	PublicCommission  string   `json:"public_commission"`
	ServiceRatio      string   `json:"service_ratio"`
	CostPrice         string   `json:"cost_price"`
	GoodsID           string   `json:"goods_id"`
	GoodsImg          string   `json:"goods_img"`
	GoodsSales        string   `json:"goods_sales"`
	GoodsTitle        string   `json:"goods_title"`
	InStock           string   `json:"in_stock"`
	Price             string   `json:"price"`
	Sharable          string   `json:"sharable"`
	ShopID            string   `json:"shop_id"`
	ShopName          string   `json:"shop_name"`
	DetailURL         string   `json:"detail_url"`
	YhqPrice          string   `json:"yhq_price"`
	Cid               string   `json:"cid"`
	ActivityStartTime string   `json:"activity_start_time"`
	ActivityEndTime   string   `json:"activity_end_time"`
	Imgs              []string `json:"imgs"`
	UpdateTime        string   `json:"update_time"`
}

type TikTokDetailData struct {
	IsCsjp           string      `json:"is_csjp"`
	Commission       string      `json:"commission"`
	PublicCommission string      `json:"public_commission"`
	CostPrice        string      `json:"cost_price"`
	GoodsID          string      `json:"goods_id"`
	GoodsImg         string      `json:"goods_img"`
	GoodsSales       string      `json:"goods_sales"`
	GoodsTitle       string      `json:"goods_title"`
	InStock          string      `json:"in_stock"`
	Price            string      `json:"price"`
	Sharable         string      `json:"sharable"`
	ShopID           string      `json:"shop_id"`
	ShopName         string      `json:"shop_name"`
	DetailUrl        string      `json:"detail_url"`
	YhqPrice         string      `json:"yhq_price"`
	Imgs             []string    `json:"imgs"`
	DetailImgs       []string    `json:"detail_imgs"`
	ShopTotalScore   interface{} `json:"shop_total_score"`
	ActivityId       string      `json:"activity_id"`
}
type ShopTotalScore struct {
	LogisticsScore struct {
		Level string `json:"level"`
		Score string `json:"score"`
		Text  string `json:"text"`
	} `json:"logistics_score"`
	ProductScore struct {
		Level string `json:"level"`
		Score string `json:"score"`
		Text  string `json:"text"`
	} `json:"product_score"`
	ServiceScore struct {
		Level string `json:"level"`
		Score string `json:"score"`
		Text  string `json:"text"`
	} `json:"service_score"`
	ShopScore struct {
		Level string `json:"level"`
		Score string `json:"score"`
		Text  string `json:"text"`
	} `json:"shop_score"`
}

func TikTokDetail(tikTokArgs map[string]interface{}) (*TikTokDetailData, error) {
	args := map[string]interface{}{
		"appkey":     tikTokArgs["appkey"],
		"secret_key": tikTokArgs["secret_key"],
		"id":         tikTokArgs["gid"],
	}
	resp, err := Send("tik_tok", "getGoodsDetail", args)
	if err != nil {
		return nil, err
	}
	var tmp struct {
		Data TikTokDetailData `json:"data"`
	}
	if err = json.Unmarshal(resp, &tmp); err != nil {
		return nil, err
	}
	return &tmp.Data, nil
}
func TikTokDetailSku(tikTokArgs map[string]interface{}) (*md.SkuData, error) {
	args := map[string]interface{}{
		"appkey":     tikTokArgs["appkey"],
		"secret_key": tikTokArgs["secret_key"],
		"id":         tikTokArgs["gid"],
	}
	resp, err := Send("tik_tok", "getGoodsDetailSku", args)
	if err != nil {
		return nil, err
	}
	respstr := strings.ReplaceAll(string(resp), "\"pictures\":[]", "\"pictures\":{}")
	var tmp struct {
		Data md.SkuData `json:"data"`
	}
	resp = []byte(respstr)
	if err = json.Unmarshal(resp, &tmp); err != nil {
		return nil, err
	}
	return &tmp.Data, nil
}
func TikTokGoods(tikTokArgs map[string]interface{}) (*[]TikTokData, error) {
	args := map[string]interface{}{
		"appkey":        tikTokArgs["appkey"],
		"secret_key":    tikTokArgs["secret_key"],
		"title":         tikTokArgs["keyword"],
		"first_cids":    tikTokArgs["category_id"],
		"price_min":     zhios_third_party_utils.AnyToString(tikTokArgs["start_price"]),
		"price_max":     zhios_third_party_utils.AnyToString(tikTokArgs["end_price"]),
		"sell_num_min":  zhios_third_party_utils.AnyToString(tikTokArgs["start_sales"]),
		"sell_num_max":  zhios_third_party_utils.AnyToString(tikTokArgs["end_sales"]),
		"sort":          tikTokArgs["sort"],
		"cos_ratio_min": zhios_third_party_utils.AnyToString(tikTokArgs["start_commission"]),
		"cos_ratio_max": zhios_third_party_utils.AnyToString(tikTokArgs["end_commission"]),
		"page":          tikTokArgs["p"],
		"page_size":     tikTokArgs["size"],
	}
	for k, v := range args {
		if v == nil || v == "<nil>" {
			args[k] = ""
		}
	}
	resp, err := Send("tik_tok", "getGoods", args)
	if err != nil {
		return nil, err
	}
	var tmp struct {
		Data []TikTokData `json:"data"`
	}
	if err = json.Unmarshal(resp, &tmp); err != nil {
		return nil, err
	}
	return &tmp.Data, nil
}
func TikTokDetailMore(tikTokArgs map[string]interface{}) (*[]TikTokDetailData, error) {
	args := map[string]interface{}{
		"appkey":     tikTokArgs["appkey"],
		"secret_key": tikTokArgs["secret_key"],
		"id":         tikTokArgs["gid"],
	}
	resp, err := Send("tik_tok", "getGoodsDetailMore", args)
	if err != nil {
		return nil, err
	}
	var tmp struct {
		Data map[string]TikTokDetailData `json:"data"`
	}
	data := make([]TikTokDetailData, 0)
	if err = json.Unmarshal(resp, &tmp); err != nil {
		return nil, err
	}
	for _, v := range tmp.Data {
		data = append(data, v)
	}
	return &data, nil
}
func TikTokGoodsKl(tikTokArgs map[string]interface{}) (*TikTokDetailData, error) {
	args := map[string]interface{}{
		"appkey":     tikTokArgs["appkey"],
		"secret_key": tikTokArgs["secret_key"],
		"content":    php2go.Base64Encode(tikTokArgs["content"].(string)),
	}
	for k, v := range args {
		if v == nil || v == "<nil>" {
			args[k] = ""
		}
	}
	resp, err := Send("tik_tok", "getKlGoods", args)
	if err != nil {
		return nil, err
	}
	var tmp struct {
		Data TikTokDetailData `json:"data"`
	}
	if err = json.Unmarshal(resp, &tmp); err != nil {
		return nil, err
	}
	return &tmp.Data, nil
}
func TikTokGoodsKlNew(tikTokArgs map[string]interface{}) (*TikTokDetailData, error) {
	args := map[string]interface{}{
		"appkey":     tikTokArgs["appkey"],
		"secret_key": tikTokArgs["secret_key"],
		"content":    php2go.Base64Encode(tikTokArgs["content"].(string)),
	}
	for k, v := range args {
		if v == nil || v == "<nil>" {
			args[k] = ""
		}
	}
	resp, err := Send("tik_tok", "getKlGoodsId", args)
	if err != nil {
		return nil, err
	}
	var tmp struct {
		Data TikTokDetailData `json:"data"`
	}
	if err = json.Unmarshal(resp, &tmp); err != nil {
		return nil, err
	}
	if zhios_third_party_utils.StrToFloat64(tmp.Data.YhqPrice) > 0 {
		tmp.Data.Price = tmp.Data.CostPrice
	}
	return &tmp.Data, nil
}
