package zhimeng

import (
	"code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/md"
	"encoding/json"
	"github.com/syyongx/php2go"
)

type TikTokUrlData struct {
	Deeplink  string `json:"deeplink"`
	Content   string `json:"content"`
	QrCode    string `json:"qr_code"`
	Link      string `json:"link"`
	AppId     string `json:"app_id"`
	PageUrl   string `json:"page_url"`
	ShareLink string `json:"share_link"`
}

func TikTokUrl(tikTokArgs map[string]interface{}) (*md.ConvertedUrls, error) {
	args := map[string]interface{}{
		"appkey":        tikTokArgs["appkey"],
		"secret_key":    tikTokArgs["secret_key"],
		"product_url":   tikTokArgs["product_url"],
		"external_info": tikTokArgs["external_info"],
		"need_qr_code":  tikTokArgs["need_qr_code"],
	}
	resp, err := Send("tik_tok", "getUrls", args)
	if err != nil {
		return nil, err
	}
	var tmp struct {
		Data TikTokUrlData `json:"data"`
	}
	if err = json.Unmarshal(resp, &tmp); err != nil {
		return nil, err
	}
	content, _ := php2go.Base64Decode(tmp.Data.Content)
	return &md.ConvertedUrls{
		URL:          tmp.Data.Deeplink,
		ShortenURL:   tmp.Data.Deeplink,
		NoOpenAppURL: tmp.Data.Deeplink,
		AppURL:       tmp.Data.Deeplink,
		ClickUrl:     tmp.Data.Deeplink,
		H5Url:        tmp.Data.ShareLink,
		QrcodeUrl:    tmp.Data.QrCode,
		Content:      content,
	}, nil
}

func TikTokActUrl(tikTokArgs map[string]interface{}) (*md.ConvertedUrls, error) {
	args := map[string]interface{}{
		"appkey":          tikTokArgs["appkey"],
		"secret_key":      tikTokArgs["secret_key"],
		"activity_id":     tikTokArgs["material_id"],
		"mix_activity_id": tikTokArgs["material_id"],
		"need_qr_code":    tikTokArgs["need_qr_code"],
		"external_info":   tikTokArgs["external_info"],
	}
	resp, err := Send("tik_tok", "getActUrls", args)
	if err != nil {
		return nil, err
	}
	var tmp struct {
		Data TikTokUrlData `json:"data"`
	}
	if err = json.Unmarshal(resp, &tmp); err != nil {
		return nil, err
	}
	content, _ := php2go.Base64Decode(tmp.Data.Content)
	return &md.ConvertedUrls{
		URL:          tmp.Data.Deeplink,
		ShortenURL:   tmp.Data.Deeplink,
		NoOpenAppURL: tmp.Data.Deeplink,
		AppURL:       tmp.Data.Deeplink,
		ClickUrl:     tmp.Data.Deeplink,
		QrcodeUrl:    tmp.Data.QrCode,
		Content:      content,
	}, nil
}
